﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;

namespace DragDropSample.ViewModels
{
    public class MyViewModel:INotifyPropertyChanged
    {
        public static IList<MyViewModel> GetItems(string name)
        {
            var result = new ObservableCollection<MyViewModel>();
            foreach (var num in Enumerable.Range(1, 15))
            {
                var item = new  MyViewModel();
                item.DateCreated = DateTime.Today.AddDays(-num % 5);
                item.Price = num*100 + Convert.ToDouble(num)/100;
                item.Title = String.Format("{0} {1}", name, num);

                result.Add(item);
            }
            return result;
        }

        private double price;
        public double Price
        {
            get
            {
                return this.price;
            }
            set
            {
                if (this.price != value)
                {
                    this.price = value;
                    OnPropertyChanged("Price");
                }
            }
        }

        private DateTime dateCreated;
        public DateTime DateCreated
        {
            get
            {
                return this.dateCreated;
            }
            set
            {
                if (this.dateCreated != value)
                {
                    this.dateCreated = value;
                    OnPropertyChanged("DateCreated");
                }
            }
        }

        private String title;
        public String Title
        {
            get
            {
                return this.title;
            }
            set
            {
                if (this.title != value)
                {
                    this.title = value;
                    OnPropertyChanged("Title");
                }
            }
        }

        /// <summary>
        ///     Called when the value of a property changes.
        /// </summary>
        /// <param name="propertyName">The name of the property that has changed.</param>
        protected virtual void OnPropertyChanged(String propertyName)
        {
            if (String.IsNullOrEmpty(propertyName))
            {
                return;
            }
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        /// <summary>
        ///     Raised when the value of one of the properties changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;
    }
}
