﻿Imports System.Collections
Imports System.Windows
Imports System.Windows.Controls
Imports Telerik.Windows.Controls
'NOTE: We need this namespace.
Imports Telerik.Windows.Controls.DragDrop
Imports System
Imports DragDropSampleVB.DragDropSample.ViewModels


Partial Public Class MainPage
    Inherits UserControl

    Public Sub New()
        RadDragAndDropManager.DragStartThreshold = 2

        InitializeComponent()

        listBoxElement.ItemsSource = MyViewModel.GetItems("ListBox Item")
        gridViewElement.ItemsSource = MyViewModel.GetItems("GridView Item")

        'There are two sides of a DragDrop, a source side which "supplies"
        'the payload and a destination side which can accept the payload 
        '(and the DragDrop). There are also two types of events. Events that 
        'ask us if something should be possible and events that notify us
        'that somethinng that just happened (Query and Info events respectively). 

        'Here we add handlers for the source side
        RadDragAndDropManager.AddDragQueryHandler(Me, AddressOf OnDragQuery)
        RadDragAndDropManager.AddDragInfoHandler(Me, AddressOf OnDragInfo)

        'And the handlers for the destination side.
        RadDragAndDropManager.AddDropQueryHandler(Me, AddressOf OnDropQuery)
        RadDragAndDropManager.AddDropInfoHandler(Me, AddressOf OnDropInfo)
    End Sub

    Private Sub OnDropQuery(ByVal sender As Object, ByVal e As DragDropQueryEventArgs)
        'Again, we handle the drop query at a root leve, but we could
        'add the handler to a specific control if we want more granularity.
        If e.Options.Status = DragStatus.DropDestinationQuery Then
            'We would only check that the source and the destination are
            'different
            e.QueryResult = Not Object.Equals(e.Options.Destination, e.Options.Source)
            e.Handled = True
        End If
    End Sub

    Private Sub OnDropInfo(ByVal sender As Object, ByVal e As DragDropEventArgs)
        'Here we can change the drag cue to let the user know what
        'action is possible. We could change the background of the
        'arrow if it is in use.
        If e.Options.Status = DragStatus.DropPossible Then
            'Drop is possible, change the content of the DragCue or 
            'notify the user that a drag is possible.
        End If

        If e.Options.Status = DragStatus.DropImpossible Then
            'Drop is not possible. Here generally we will revert the changes
            'done in DropPossible.
        End If

        If e.Options.Status = DragStatus.DropComplete Then
            'Here we can generally check the payload and add handle the case
            'when it is an IEnumerable (when multiple items are dragged).
            'The paylaod could also be a custom class that contains mroe info
            'for the DragDrop. HEre we know that it always is an item that we can 
            'display. We just add the item here, we do not interact with the
            'drag source. Removing the item (if at all removed should happen OnDragIndo
            'so that there will be separation of handling the DragDrop, which is more flexible.
            Dim itemsSource As IList = Nothing
            If TypeOf e.Options.Destination Is System.Windows.Controls.ListBox Then
                itemsSource = TryCast(TryCast(e.Options.Destination, System.Windows.Controls.ListBox).ItemsSource, IList)
            Else
                itemsSource = TryCast(TryCast(e.Options.Destination, RadGridView).ItemsSource, IList)
            End If

            itemsSource.Add(e.Options.Payload)
        End If
    End Sub

    Private Sub OnDragInfo(ByVal sender As Object, ByVal e As DragDropEventArgs)
        'We want to remove the item on a successful drop. But we have added
        'this event handler to the root visual, we have to then check the 
        'drag source here. Alternatively we can add separates handlers to 
        'the different controls.
        If e.Options.Status = DragStatus.DragComplete Then
            Dim itemsSource As IList = Nothing
            If TypeOf e.Options.Destination Is System.Windows.Controls.ListBox Then
                itemsSource = TryCast(TryCast(e.Options.Destination, System.Windows.Controls.ListBox).ItemsSource, IList)
            Else
                itemsSource = TryCast(TryCast(e.Options.Destination, RadGridView).ItemsSource, IList)
            End If

            itemsSource.Remove(e.Options.Payload)
        End If
    End Sub

    Private Sub OnDragQuery(ByVal sender As Object, ByVal e As DragDropQueryEventArgs)
        'We are asked here if the item should be dragged:
        If e.Options.Status = DragStatus.DragQuery Then
            'The answer is yes, but we can get e.Options.Source and 
            'check the item for something and only then allow it.
            e.QueryResult = True

            'Generally it is a good idea to handle routed events if 
            'we are taking some action.
            e.Handled = True

            'We want to make sure that the payload is something maningful that can
            'be used by the destination side. We could simply add the dragged item (or items)
            'or we could create a custom class that will provide more information in
            'a complex app.
            'Here we get the ViewModel iitem. We could get the selected items of a cotnrol
            'for multiple items DragDrop.
            e.Options.Payload = TryCast(e.Source, FrameworkElement).DataContext

            'We can decide to add a drag cue here
            'to help the user. We can add any ContentControl as a
            'drag cue but we can also generate an arrow because it is easier:
            e.Options.ArrowCue = RadDragAndDropManager.GenerateArrowCue()
        End If

        'The question here is if the source item can be dropped,
        'again we can say yes/no depending on some rules.
        If e.Options.Status = DragStatus.DropSourceQuery Then
            e.QueryResult = True
            e.Handled = True
        End If
    End Sub



End Class
